import { FirstChart } from "@/Components/FirstChart";
import AuthenticatedLayout from "@/Layouts/AuthenticatedLayout";
import { Head, router } from "@inertiajs/react";
import { useCallback, useState } from "react";
import { useSearchParam } from "react-use";
import { PageProps } from "@/types";
import { ChangeEvent } from "react";
import { InfoCard } from "@/Components/ui/InfoCard";
import {
    Select,
    SelectContent,
    SelectItem,
    SelectTrigger,
    SelectValue,
} from "@/Components/ui/select";
import { DataBarChart } from "@/Components/DataBarChart";
import { DataPieChart } from "@/Components/DataPieChart";

export default function Dashboard({
    total_impressions,
    total_clicks,
    total_requests,
    total_revenue,
    sites,
}: any) {
    const dateRanges = [
        { value: "TODAY" },
        { value: "YESTERDAY" },
        { value: "LAST_WEEK" },
        { value: "LAST_MONTH" },
        { value: "LAST_3_MONTHS" },
        { value: "REACH_LIFETIME" },
    ];
    console.log(sites);

    const siteNames = () => {
        return sites.map((site: any) => ({
            name: site.site_name,
        }));
    };

    const siteData = () =>{
        return sites.map((site: any) => ({
            name: site.site_name,
            total_revenue: site.total_revenue,
        }));
    }

    const params = useSearchParam("search");

    const [originParam, setOriginParam] = useState(params ?? "");

    const searchSites = useCallback(
        (e: ChangeEvent<HTMLInputElement>) => {
            setOriginParam(e.target.value);
            const currentRoute = route().current();

            const dateRange = new URLSearchParams(window.location.search).get(
                "date_range"
            );
            const request: { search?: string; date_range?: string | null } = {};
            if (e.target.value) {
                request.search = e.target.value;
            }
            if (dateRange) {
                request.date_range = dateRange;
            }

            if (currentRoute) {
                router.get(
                    currentRoute,
                    {
                        date_range: dateRange,
                    },
                    {
                        replace: true,
                        preserveState: true,
                    }
                );
            } else {
                // Handle the case where the current route is undefined (fallback to a default route or show an error)
                console.error("Current route is undefined");
            }
        },
        [originParam]
    );

    return (
        <AuthenticatedLayout
            header={
                <h2 className="text-xl font-semibold leading-tight text-gray-800">
                    Dashboard
                </h2>
            }
        >
            <Head title="Dashboard" />

            <div>
                <div className={"flex mx-4 gap-2 px-4 py-8"}>
                    <Select
                        onValueChange={(value) => {
                            const currentRoute = route().current();
                            if (currentRoute) {
                                router.get(
                                    currentRoute,
                                    {
                                        search: originParam,
                                        date_range: value,
                                    },
                                    {
                                        replace: true,
                                        preserveState: true,
                                    }
                                );
                            }
                        }}
                    >
                        <SelectTrigger className="w-[180px]">
                            <SelectValue placeholder="Select Date Range" />
                        </SelectTrigger>
                        <SelectContent>
                            {dateRanges.map((item) => (
                                <SelectItem key={item.value} value={item.value}>
                                    {item.value}
                                </SelectItem>
                            ))}
                        </SelectContent>
                    </Select>
                </div>
            </div>
            <div className="grid xl:grid-cols-5 lg:grid-cols-4 md:grid-cols-3 grid-cols-1 lg:gap-6 gap-4 w-full px-4 sm:px-8 text-sm sm:text-base z-50">
                {[
                    {
                        title: "Total Impressions",
                        value: total_impressions / 1000 + "K",
                        bgColor: "bg-yellow-200",
                    },
                    {
                        title: "Total Clicks",
                        value: total_clicks / 1000 + "K",
                        bgColor: "bg-yellow-200",
                    },
                    {
                        title: "Total Requests",
                        value: total_requests / 1000 + "K",
                        bgColor: "bg-red-200",
                    },
                    {
                        title: "Total Revenue",
                        value: total_revenue,
                        bgColor: "bg-green-200",
                    },
                ].map((item, index) => (
                    <InfoCard
                        key={index}
                        title={item.title}
                        value={item.value}
                        bgColor={item.bgColor}
                        index={index}
                    />
                    // <div
                    //     key={index}
                    //     className="flex flex-col items-center justify-center w-full sm:w-[22%] p-4 bg-red-300 rounded-lg shadow-md"
                    // >
                    //     <p className="text-white font-medium">{item.title}</p>
                    //     <p className="text-white text-lg font-bold mt-1">
                    //         {item.value}
                    //         {index == 3 ? " $" : ""}
                    //     </p>
                    // </div>
                ))}
            </div>

            <div className="py-8">
                <div className="sm:px-8 px-4">
                    {/* <div className="overflow-hidden bg-white shadow-sm sm:rounded-lg">
                        <div className="p-6 text-gray-900">
                            <FirstChart />
                        </div>
                    </div> */}
                    <div className="grid lg:grid-cols-2 gap-6 gap-y-10 mt-4">
                        <div>
                            <DataBarChart data={siteData()} />
                        </div>
                        <div>
                        <DataPieChart data={siteData()} />

                        </div>
                    </div>
                </div>
            </div>
        </AuthenticatedLayout>
    );
}
